==> haskell-pointed-5.0.1-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-pointed.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pointed
version: 5.0.1
id: pointed-5.0.1-J18GSi1WWqrFaLTkn9UIVv
key: pointed-5.0.1-J18GSi1WWqrFaLTkn9UIVv
license: BSD3
copyright: Copyright (C) 2008-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/pointed/
synopsis: Pointed and copointed data
description:
    Pointed and copointed data.
category: Data
author: Edward A. Kmett
exposed: True
indefinite: False
exposed-modules:
    Data.Copointed Data.Pointed
abi: bb074272484d4bb74fc7a0941045de2a
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/pointed-5.0.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/pointed-5.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/pointed-5.0.1
hs-libraries: HSpointed-5.0.1-J18GSi1WWqrFaLTkn9UIVv
depends:
    base-4.10.1.0 comonad-5.0.2-39Ld6hwW25rA6T0xM0ORgi
    containers-0.5.10.2
    data-default-class-0.1.2.0-ImBMrJK18PFLLtssITDnZ5
    hashable-1.2.6.1-6LeHpYZ4iRgEy9P36eCQfR
    kan-extensions-5.1-7rJmI8v1W6tKClDNwIcSxu
    semigroupoids-5.2.2-H3vVykFCBM9AAd2ZXrJhKu
    semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q
    stm-2.4.5.0-7j9Z9j03i0pHiTKIV2qS3x
    tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2 transformers-0.5.2.0
    transformers-compat-0.5.1.4-EAh8Ccrgitz4vTZtbTPyCM
    unordered-containers-0.2.8.0-YOGDwOwys3HjU5i3g27KB
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             comonad-5.0.2-39Ld6hwW25rA6T0xM0ORgi=214c61295c028939ff62ffdb1992a893
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             data-default-class-0.1.2.0-ImBMrJK18PFLLtssITDnZ5=59d0190781dd74e9cf2161eb5998f2f1
             hashable-1.2.6.1-6LeHpYZ4iRgEy9P36eCQfR=e2c3f4e35e60b5547d3e7a8c501ca6de
             kan-extensions-5.1-7rJmI8v1W6tKClDNwIcSxu=7d301c71d524313ca95f4ae73c5d8e53
             semigroupoids-5.2.2-H3vVykFCBM9AAd2ZXrJhKu=11ef36f6619c1a365fec471bc9bec34d
             semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q=0f8a4b2bc8ee8ce3a5dab66f0eb14e7c
             stm-2.4.5.0-7j9Z9j03i0pHiTKIV2qS3x=ad6bbd8e6ded9502ff897b95774cdf26
             tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2=b5d07becd47ba21e20b584b61ad0f06d
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             transformers-compat-0.5.1.4-EAh8Ccrgitz4vTZtbTPyCM=506de314acc216de1ce76634db1785eb
             unordered-containers-0.2.8.0-YOGDwOwys3HjU5i3g27KB=1ae4406c8abf6f6a305796d42b6e1b7b
haddock-interfaces: /usr/share/doc/haskell-pointed/html/pointed.haddock
haddock-html: /usr/share/doc/haskell-pointed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pointed-5.0.1-10-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-pointed.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pointed
version: 5.0.1
id: pointed-5.0.1-La8CNzhY0sc3CPYjrHhLO4
key: pointed-5.0.1-La8CNzhY0sc3CPYjrHhLO4
license: BSD3
copyright: Copyright (C) 2008-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/pointed/
synopsis: Pointed and copointed data
description:
    Pointed and copointed data.
category: Data
author: Edward A. Kmett
exposed: True
indefinite: False
exposed-modules:
    Data.Copointed Data.Pointed
abi: 2791fed0afd1151e9f67fb7046822798
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/pointed-5.0.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/pointed-5.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/pointed-5.0.1
hs-libraries: HSpointed-5.0.1-La8CNzhY0sc3CPYjrHhLO4
depends:
    base-4.10.1.0 comonad-5.0.3-1wQLfIXhDc15HcgpkWgfSP
    containers-0.5.10.2
    data-default-class-0.1.2.0-ImBMrJK18PFLLtssITDnZ5
    hashable-1.2.6.1-6LeHpYZ4iRgEy9P36eCQfR
    kan-extensions-5.1-EcqSUpQe0TcC1YLKtOfhuI
    semigroupoids-5.2.2-H3PzwRIhGuF7pmQc9pykYR
    semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q
    stm-2.4.5.0-7j9Z9j03i0pHiTKIV2qS3x
    tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2 transformers-0.5.2.0
    transformers-compat-0.5.1.4-EAh8Ccrgitz4vTZtbTPyCM
    unordered-containers-0.2.9.0-14GJxyni7Ou4ztgK034uJm
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             comonad-5.0.3-1wQLfIXhDc15HcgpkWgfSP=0772d58444b5fab8850dd1c606485ec5
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             data-default-class-0.1.2.0-ImBMrJK18PFLLtssITDnZ5=59d0190781dd74e9cf2161eb5998f2f1
             hashable-1.2.6.1-6LeHpYZ4iRgEy9P36eCQfR=e2c3f4e35e60b5547d3e7a8c501ca6de
             kan-extensions-5.1-EcqSUpQe0TcC1YLKtOfhuI=4cdea27985064ea64b28994725711d39
             semigroupoids-5.2.2-H3PzwRIhGuF7pmQc9pykYR=08dfd1056229bca771938046c8a0dab3
             semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q=0f8a4b2bc8ee8ce3a5dab66f0eb14e7c
             stm-2.4.5.0-7j9Z9j03i0pHiTKIV2qS3x=ad6bbd8e6ded9502ff897b95774cdf26
             tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2=b5d07becd47ba21e20b584b61ad0f06d
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             transformers-compat-0.5.1.4-EAh8Ccrgitz4vTZtbTPyCM=506de314acc216de1ce76634db1785eb
             unordered-containers-0.2.9.0-14GJxyni7Ou4ztgK034uJm=a19fc431946ec4b21dbc4dc9d0f6448c
haddock-interfaces: /usr/share/doc/haskell-pointed/html/pointed.haddock
haddock-html: /usr/share/doc/haskell-pointed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
